import os as _os


def _set_credentials():
    try:
        home = _os.path.expanduser("~")
        with open(home + '/.pypi_umihico_env', 'r') as f:
            for line in f.readlines():
                key, password = line.split(',')
                _os.environ[key] = password.replace('\n', '')
    except Exception as e:
        pass


_set_credentials()


def _set_env_value(getenv_key, optional_value=None):
    """
    example
    def send_line(message, receiver_api_key=None):
        receiver_api_key = _set_env_value('line_api_key', receiver_api_key)
    """
    value = _os.getenv(getenv_key) or optional_value
    if not value:
        raise Exception(f"{getenv_key} is not defined")
    return value


if __name__ == '__main__':
    import api
    import scraping
    print([_os.environ['line_api_key'], ])
    api.line.send_line('test', receiver_api_key=None)
else:
    from . import api
    from . import scraping




def elements_to_strings_list(lxml_elements):
    lxml_elements = lxml_elements if isinstance(
        lxml_elements, list) else [lxml_elements, ]
    return [str(element.text_content() if isinstance(
        element, _ElementBase) else element) for element in lxml_elements]



import boto3 as _boto3


def gen_s3(key, secret_key, region_name):
    """
    gen s3 by keys instead of "boto3.resource('s3')"
    when you didn't do "aws configure" well
    """
    s3 = _boto3.session.Session(
        key=key, secret_key=secret_key, region_name=region_name).resource('s3')
    return s3


def download_text(bucketname, path, s3=None):
    s3 = s3 or _boto3.resource('s3')
    obj = s3.Object(bucketname, path)
    text = obj.get()['Body'].read().decode('utf-8')
    return text


def upload_text(bucketname, path, text, public_read=False, ContentType='text/plain', s3=None):
    s3 = s3 or _boto3.resource('s3')
    acl = {True: "public-read",
           False: "private"}[public_read]
    response = s3.Bucket(bucketname).put_object(ACL=acl, Body=text,
                                                Key=path, ContentType=ContentType)





import requests as _requests
import json as _json


def trigger_via_apigateway(url, api_key=None, payload=None):
    method = "POST" if payload else "GET"
    kw = {}
    if api_key:
        kw['headers'] = {'x-api-key': api_key, }
    if payload:
        kw['data'] = _json.dumps(payload)
    return _requests.request(method, url, **kw)


if __name__ == '__main__':
    def test_trigger_via_apigateway():
        payload = {
            "api_key": "test!",
        }
        # not valid url and key, don't worry
        url = "https://k0ch7iuaj4.execute-api.us-west-2.amazonaws.com/default/asyc_superfast_receiver"
        api_key = "JJnYqNMTBU1LdIEjaSYL43G4OGfysL9B1In5oPoy"
        return trigger_via_apigateway(url, api_key, payload)

    import ast

    def lambda_handler(event, context):
        """returns "test!"  if lambda_handler is like this."""
        payload = ast.literal_eval(event['body'])
        return {
            "statusCode": 200,
            "body": payload['api_key']
        }

    response = test_trigger_via_apigateway()
    print(response.text)



from setuptools import setup, find_packages


requirements = [
    "requests",
    "boto3",
]


def _version_increment():
    with open('version.txt', 'r') as f:
        version = int(float(f.read()))
    version += 1
    version = str(version)
    with open('version.txt', 'w') as f:
        f.write(version)
    version = '.'.join(str(version).zfill(3))
    return version


setup(
    name='umihico',
    version=_version_increment(),
    description="my common functions",
    url='https://github.com/umihico/umihico',
    author='umihico',
    author_email='umihico_dummy@users.noreply.github.com',
    license='MIT',
    keywords='umihico',
    packages=find_packages(),
    install_requires=requirements,
    classifiers=[
        'Programming Language :: Python :: 3.6',
    ],
)



import requests as _requests
from urllib.parse import urlparse as _urlparse
_base_headers = {
    "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8",
    "Accept-Encoding": "gzip, deflate, br",
    "Connection": "keep-alive",
    "Upgrade-Insecure-Requests": "1",
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/69.0.3497.100 Safari/537.36", }


def get(url, header_lang="ja,en-US;q=0.9,en;q=0.8", proxy=None):
    headers = _base_headers.copy()
    if header_lang:
        headers['Accept-Language'] = header_lang
    headers['Host'] = _urlparse(url).netloc
    kw = {"headers": headers, }
    if proxy:
        kw['proxies'] = {'http': 'http://' + proxy,
                         'https': 'http://' + proxy, }
    return _requests.get(url, **kw)


if __name__ == '__main__':
    print(get("https://www.nasdaq.com/").status_code)
